onOutgoing abstract method
Register a callback that will be called for every outgoing data event that
the owner of this WSocket instance adds.
data will either be the single data item or the stream, depending on
whether add() or addStream() was called.
Implementation
@Deprecated(v3Deprecation)
void onOutgoing(callback(dynamic data));