delete abstract method
Send a DELETE request.
If uri is given, the request will be sent to that exact uri. If uri is
null, the uri on the BaseRequest will be used (and is thus required).
If headers is given, they will be merged with the set of headers
already defined on the BaseRequest.
Implementation
Future<Response> delete({Map<String, String>? headers, Uri? uri});